@@ -1,2 +1,2 @@
 from mlsdatascrape.LeagueData import LeagueData
-from mlsdatascrape.utils.Parser import Parser
+from mlsdatascrape.Parser import Parser
